.. _contents:

NetworkX documentation
======================

.. only:: html

    :Release: |version|
    :Date: |today|

    :download:`Tutorial (PDF)  <networkx_tutorial.pdf>`

    :download:`Reference (PDF)  <networkx_reference.pdf>`

    :download:`Tutorial+Reference (HTML zip)  <networkx-documentation.zip>`

.. toctree::
   :maxdepth: 2

   overview
   download
   install
   tutorial/index
   reference/index
   test
   reference/history
   bibliography


.. only:: html

   - `Examples <examples/index.html>`_

.. only:: html

   - `Gallery <gallery.html>`_




   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`

